==> litecoin-0.10.2.2.tar.gz: litecoin-0.10.2.2/src/qt/locale/bitcoin_af_ZA.ts <==
<TS language="af_ZA" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Skep 'n nuwe adres</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Maak 'n kopie van die huidige adres na die stelsel klipbord</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwyder</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Enter passphrase</source>
        <translation>Tik Wagwoord in</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nuwe wagwoord</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Herhaal nuwe wagwoord</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Enkripteer beursie</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Hierdie operasie benodig 'n wagwoord om die beursie oop te sluit.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Sluit beursie oop</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Hierdie operasie benodig 'n wagwoord om die beursie oop te sluit.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Sluit beursie oop</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Verander wagwoord</translation>
    </message>
    <message>
        <source>Enter the old and new passphrase to the wallet.</source>
        <translation>Tik asseblief die ou en nuwe wagwoord vir die beursie in.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bevestig beursie enkripsie.</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Die beursie is nou bewaak</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Die beursie kon nie bewaak word nie</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Beursie bewaaking het misluk as gevolg van 'n interne fout. Die beursie is nie bewaak nie!</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Die wagwoord stem nie ooreen nie</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Beursie oopsluiting het misluk</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Die wagwoord wat ingetik was om die beursie oop te sluit, was verkeerd.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Beursie dekripsie het misluk</translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sinchroniseer met die netwerk ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Oorsig</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Wys algemene oorsig van die beursie</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksies</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Besoek transaksie geskiedenis</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;luit af</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Sluit af</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Wys inligting oor Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsies</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Beursie</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Lêer</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellings</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Blad nutsbalk</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 agter</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Ontvangs van laaste blok is %1 terug.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasie</translation>
    </message>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Maak kopie van adres</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>New receiving address</source>
        <translation>Nuwe ontvangende adres</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nuwe stuurende adres</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Wysig ontvangende adres</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Wysig stuurende adres</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Kon nie die beursie oopsluit nie.</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Usage:</source>
        <translation>Gebruik:</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsies</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Informasie</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Stuur Munstukke</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Stuur aan vele ontvangers op eens</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Balans:</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>S&amp;tuur</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>Message:</source>
        <translation>Boodskap:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Teken boodskap</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Handtekening</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Teken &amp;Boodskap</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>From</source>
        <translation>Van</translation>
    </message>
    <message>
        <source>To</source>
        <translation>Na</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>eie adres</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiket</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Krediet</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>nie aanvaar nie</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debiet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transaksie fooi</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Netto bedrag</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation>Transaksie ID</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>true</source>
        <translation>waar</translation>
    </message>
    <message>
        <source>false</source>
        <translation>onwaar</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>onbekend</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ontvang met</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation>Ontvang van</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Gestuur na</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Betalings Aan/na jouself</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Gemyn</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(n.v.t)</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation>Datum en tyd wat die transaksie ontvang was.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation>Tipe transaksie.</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Vandag</translation>
    </message>
    <message>
        <source>This week</source>
        <translation>Hierdie week</translation>
    </message>
    <message>
        <source>This month</source>
        <translation>Hierdie maand</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation>Verlede maand</translation>
    </message>
    <message>
        <source>This year</source>
        <translation>Hierdie jaar</translation>
    </message>
    <message>
        <source>Range...</source>
        <translation>Reeks...</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Ontvang met</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Gestuur na</translation>
    </message>
    <message>
        <source>To yourself</source>
        <translation>Aan/na jouself</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Gemyn</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ander</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation>Min bedrag</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Maak kopie van adres</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation>Reeks:</translation>
    </message>
    <message>
        <source>to</source>
        <translation>aan</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Stuur Munstukke</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>Opsies:</translation>
    </message>
    <message>
        <source>Use the test network</source>
        <translation>Gebruik die toets netwerk</translation>
    </message>
    <message>
        <source>Error: Disk space is low!</source>
        <translation>Fout: Hardeskyf spasie is baie laag!</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasie</translation>
    </message>
    <message>
        <source>This help message</source>
        <translation>Hierdie help boodskap</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Laai adresse...</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Onvoldoende fondse</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Laai blok indeks...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Laai beursie...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Klaar gelaai</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
</TS>

==> litecoin-0.13.2.tar.gz: litecoin-0.13.2/src/qt/locale/bitcoin_af_ZA.ts <==
<TS language="af_ZA" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Skep 'n nuwe adres</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Maak 'n kopie van die huidige adres na die stelsel klipbord</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Verwyder</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Wagfrase Dialoog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Tik wagfrase in</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nuwe wagfrase</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Herhaal nuwe wagfrase</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Sinchroniseer met die netwerk ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Oorsig</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Wys algemene oorsig van die beursie</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksies</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Besoek transaksie geskiedenis</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>S&amp;luit af</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Sluit af</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Wys inligting oor Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsies</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Beursie</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Lêer</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellings</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hulp</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Blad nutsbalk</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 agter</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Ontvangs van laaste blok is %1 terug.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasie</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiket</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adres</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Usage:</source>
        <translation>Gebruik:</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsies</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>&amp;Beursie</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Informasie</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Bedrag:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Boodskap:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Stuur Munstukke</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Onvoldoende fondse</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Transaksie fooi:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Stuur aan vele ontvangers op eens</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Balans:</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>S&amp;tuur</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>&amp;Bedrag:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Boodskap:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Teken boodskap</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Handtekening</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation>Teken &amp;Boodskap</translation>
    </message>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Options:</source>
        <translation>Opsies:</translation>
    </message>
    <message>
        <source>Error: Disk space is low!</source>
        <translation>Fout: Hardeskyf spasie is baie laag!</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasie</translation>
    </message>
    <message>
        <source>Loading addresses...</source>
        <translation>Laai adresse...</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Onvoldoende fondse</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Laai blok indeks...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Laai beursie...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Klaar gelaai</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
</TS>
